{
    "$graph": [
        {
            "class": "Workflow",
            "doc": "This workflow describes the comparative genomics\nand genome assembly summary statistics \n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "https://hub.docker.com/cwlviewer/"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/Assembly_Stats_Files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/Fasta_Files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/GFF_Files"
                },
                {
                    "type": "File",
                    "id": "#main/Gene_Ontology"
                },
                {
                    "type": "File",
                    "id": "#main/Taxonomy_database"
                }
            ],
            "steps": [
                {
                    "run": "#clean.cwl",
                    "in": [
                        {
                            "source": "#main/Assembly_Stats_Files",
                            "id": "#main/cleaning/Assembly_Stats_Files"
                        },
                        {
                            "source": "#main/Fasta_Files",
                            "id": "#main/cleaning/Fasta_Files"
                        },
                        {
                            "source": "#main/GFF_Files",
                            "id": "#main/cleaning/GFF_Files"
                        }
                    ],
                    "out": [
                        "#main/cleaning/GFFs",
                        "#main/cleaning/Fasta",
                        "#main/cleaning/Assembly_Stats"
                    ],
                    "id": "#main/cleaning"
                },
                {
                    "run": "#data_gen.cwl",
                    "in": [
                        {
                            "source": "#main/cleaning/Assembly_Stats",
                            "id": "#main/data_gen/Assembly_Stats"
                        },
                        {
                            "source": "#main/cleaning/Fasta",
                            "id": "#main/data_gen/Fasta"
                        },
                        {
                            "source": "#main/cleaning/GFFs",
                            "id": "#main/data_gen/GFFs"
                        },
                        {
                            "source": "#main/schema_gen/Schema",
                            "id": "#main/data_gen/Schema"
                        },
                        {
                            "source": "#main/Taxonomy_database",
                            "id": "#main/data_gen/Taxonomy_database"
                        }
                    ],
                    "out": [
                        "#main/data_gen/Hadoop_Sequence_File"
                    ],
                    "id": "#main/data_gen"
                },
                {
                    "run": "#process.cwl",
                    "in": [
                        {
                            "source": "#main/schema_gen/Schema",
                            "id": "#main/process/Schema"
                        },
                        {
                            "source": "#main/data_gen/Hadoop_Sequence_File",
                            "id": "#main/process/sequence_file"
                        }
                    ],
                    "out": [
                        "#main/process/Comparative_Genomics_Stats",
                        "#main/process/Assembly_Stats"
                    ],
                    "id": "#main/process"
                },
                {
                    "run": "#schema.cwl",
                    "in": [
                        {
                            "source": "#main/Gene_Ontology",
                            "id": "#main/schema_gen/Gene_Ontology"
                        }
                    ],
                    "out": [
                        "#main/schema_gen/Schema"
                    ],
                    "id": "#main/schema_gen"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/process/Assembly_Stats",
                    "id": "#main/Assembly_Stats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process/Comparative_Genomics_Stats",
                    "id": "#main/Comparative_Genomics_Stats"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "echo",
            "label": "Data Cleaning",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/Assembly_Stats_Files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/Fasta_Files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/GFF_Files"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/Assembly_Stats"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/Fasta"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#clean.cwl/GFFs"
                }
            ],
            "id": "#clean.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "echo",
            "label": "Data Generation",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#data_gen.cwl/Assembly_Stats"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#data_gen.cwl/Fasta"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#data_gen.cwl/GFFs"
                },
                {
                    "type": "File",
                    "id": "#data_gen.cwl/Schema"
                },
                {
                    "type": "File",
                    "id": "#data_gen.cwl/Taxonomy_database"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#data_gen.cwl/Hadoop_Sequence_File"
                }
            ],
            "id": "#data_gen.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "echo",
            "label": "Query Processing",
            "inputs": [
                {
                    "type": "File",
                    "id": "#process.cwl/Schema"
                },
                {
                    "type": "File",
                    "id": "#process.cwl/sequence_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#process.cwl/Assembly_Stats"
                },
                {
                    "type": "File",
                    "id": "#process.cwl/Comparative_Genomics_Stats"
                }
            ],
            "id": "#process.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "echo",
            "label": "Schema and Compiler Generator",
            "inputs": [
                {
                    "type": "File",
                    "id": "#schema.cwl/Gene_Ontology"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#schema.cwl/Schema"
                }
            ],
            "id": "#schema.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
